package com.cardiff.client_project.mapper;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.List;

@Repository
public class CommonAdminHospitalMapper {

    @Autowired
    JdbcTemplate jdbcTemplate;

    // Query all hospital information
    public List<HospitalDTO> findAll() {
        String sql = "SELECT * FROM hospital";
        return jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(HospitalDTO.class));
    }

    // Add Hospital Information
    public int save(HospitalDTO hospital) {
        String sql = "INSERT INTO hospital (name, address, phone, totalBeds, availableBeds, occupancyRate) VALUES (?, ?, ?, ?, ?, ?)";
        return jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(), hospital.getTotalBeds(), hospital.getAvailableBeds(), hospital.getOccupancyRate());
    }

    // Update Hospital Information
    public int update(HospitalDTO hospital) {
        String sql = "UPDATE hospital SET name=?, address=?, phone=?, totalBeds=?, availableBeds=?, occupancyRate=? WHERE id=?";
        return jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(), hospital.getTotalBeds(), hospital.getAvailableBeds(), hospital.getOccupancyRate(), hospital.getId());
    }

    public List<HospitalDTO> searchHospitals(String name, String address) {
        StringBuilder sql = new StringBuilder("SELECT * FROM hospital WHERE 1=1");
        List<Object> params = new ArrayList<>();

        if (name != null && !name.trim().isEmpty()) {
            sql.append(" AND name LIKE ?");
            params.add("%" + name.trim() + "%");
        }
        if (address != null && !address.trim().isEmpty()) {
            sql.append(" AND address LIKE ?");
            params.add("%" + address.trim() + "%");
        }

        return jdbcTemplate.query(sql.toString(), new BeanPropertyRowMapper<>(HospitalDTO.class), params.toArray());
    }



}
